pub struct Vector {
pub x: f64,
pub y: f64,
}Expand description
A vector
Fields
x: f64The x component of the Vector
y: f64The y component of the Vector
Implementations
Sourceimpl Vector
impl Vector
Sourcepub fn dot_product(self, other: Self) -> f64
pub fn dot_product(self, other: Self) -> f64
Calculates the dot product of itself and another vector
Examples
use myelin_geometry::Vector;
// a · b = c
let a = Vector { x: 2.0, y: 3.0 };
let b = Vector { x: -4.0, y: 10.0 };
let c = a.dot_product(b);
assert_eq!(22.0, c);Sourcepub fn cross_product(self, other: Self) -> f64
pub fn cross_product(self, other: Self) -> f64
Calculates the cross product of itself and another vector
Examples
use myelin_geometry::Vector;
// a × b = c
let a = Vector { x: 2.0, y: 3.0 };
let b = Vector { x: -4.0, y: 10.0 };
let c = a.cross_product(b);
assert_eq!(32.0, c);Sourcepub fn normal(self) -> Self
pub fn normal(self) -> Self
Returns the vector’s normal vector, i.e. a vector that is perpendicular to this vector
Sourcepub fn magnitude(self) -> f64
pub fn magnitude(self) -> f64
Returns the magnitude of the vector, i.e. its length if viewed as a line
Sourcepub fn unit(self) -> Self
pub fn unit(self) -> Self
Returns the unit vector of this vector, i.e. a vector with the same direction and a magnitude of 1
Sourcepub fn project_onto(self, other: Self) -> Self
pub fn project_onto(self, other: Self) -> Self
Returns the projection of this vector onto another vector
Sourcepub fn rotate(self, rotation: Radians) -> Self
pub fn rotate(self, rotation: Radians) -> Self
Rotate a vector by the given amount (counterclockwise)
Sourcepub fn rotate_clockwise(self, rotation: Radians) -> Self
pub fn rotate_clockwise(self, rotation: Radians) -> Self
Rotate a vector by the given amount (clockwise)